==> check-copyright-0.1.0.tar.gz: check-copyright-0.1.0/setup.py <==
# Copyright (c) 2019 Kai Hoewelmeyer
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup
import setuptools

setup(
    name = "check-copyright",
    version = "0.1.0",
    author = "Kai Hoewelmeyer",
    entry_points={
        'console_scripts': [
            'check-copyright = check_copyright.check_copyright:check_all_files',
                ],
        },
    description = "Check copyright headers in a repository",
    license = "MIT",
    keywords = "copyright",
    packages=setuptools.find_packages(),
    url="https://gitlab.com/ptr-project/check-copyright",
    python_requires='>=3.6'
)

==> check-copyright-0.2.0.tar.gz: check-copyright-0.2.0/setup.py <==
# Copyright (c) 2019 Kai Hoewelmeyer
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup
import setuptools

setup(
    name = "check-copyright",
    version = "0.2.0",
    author = "Kai Hoewelmeyer",
    entry_points={
        'console_scripts': [
            'check-copyright = check_copyright.check_copyright:check_all_files',
                ],
        },
    description = "Check copyright headers in a repository",
    license = "MIT",
    keywords = "copyright",
    packages=setuptools.find_packages(),
    url="https://gitlab.com/ptr-project/check-copyright",
    python_requires='>=3.6',
    test_suite='nose.collector',
    tests_require=['nose'],
)
